/*
 * @Author: yuta
 * @Date: 2021-06-18 14:13:51
 * @LastEditTime: 2021-06-18 18:03:29
 * @LastEditors: yuta
 */
import {
  Alert,
  Clipboard,
  Dimensions,
  Platform,
  StatusBar,
  NativeModules,
} from 'react-native';
import InteractionManager from 'react-native/Libraries/Interaction/InteractionMixin';

const {StatusBarManager} = NativeModules;
/**
 * 统一尺寸
 * @param size  px
 * @returns {Number} dp
 */
const basePixelWidth = 375;
export function px2dp(px) {
  return (px * Dimensions.get('window').width) / basePixelWidth;
}

export const shadowDefault = {
  shadowColor: '#757AA5',
  shadowOffset: {width: 3, height: 3},
  shadowOpacity: 0.22,
  shadowRadius: 8,
  elevation: 3,
};

export const statusBarHeight = (() => {
  if (Platform.OS === 'ios') {
    return StatusBarManager.HEIGHT;
  }
  if (Platform.OS === 'android') {
    if (Platform.Version < 19) {
      return 0;
    }
    return StatusBar.currentHeight;
  }
  return 20;
})();

export function isEmpty(obj) {
  if (obj === undefined || obj == null) {
    return true;
  }
  if (Array.isArray(obj) && obj.length === 0) {
    //数组
    return true;
  } else {
    if (typeof obj === 'string' && obj.trim() === '') {
      return true;
    } //字符串
  }
  return false;
}

export function costTimeWork(func) {
  //耗时操作
  InteractionManager.runAfterInteractions(() => {
    func && typeof func === 'function' && func(); //若传的是有效方法，则回调
  });
}

export function showMsg(data) {
  Clipboard.setString(data);
  Alert.alert('【以下内容】已复制剪切板', '\n' + data + '\n');
}

export function selfOr(self, another = null) {
  //返回自己或者另一个对象
  if (Array.isArray(self)) {
    return !isEmpty(self) ? self : [];
  } else {
    return !isEmpty(self) ? self : another;
  }
}

export function dateFormat(
  dateTime = new Date().valueOf(),
  format = 'yyyy-MM-dd',
) {
  if (/^\d{4}-\d{1,2}-\d{1,2}$/.test(dateTime)) {
    return dateTime;
  }
  let date = new Date(dateTime);
  let o = {
    'M+': date.getMonth() + 1, //月份
    'd+': date.getDate(), //日
    'h+': date.getHours(), //小时
    'm+': date.getMinutes(), //分
    's+': date.getSeconds(), //秒
    'q+': Math.floor((date.getMonth() + 3) / 3), //季度
    S: date.getMilliseconds(), //毫秒
  };
  if (/(y+)/.test(format)) {
    format = format.replace(
      RegExp.$1,
      (date.getFullYear() + '').substr(4 - RegExp.$1.length),
    );
  }
  for (let k in o) {
    if (new RegExp('(' + k + ')').test(format)) {
      format = format.replace(
        RegExp.$1,
        RegExp.$1.length === 1
          ? o[k]
          : ('00' + o[k]).substr(('' + o[k]).length),
      );
    }
  }
  return format;
}
