/*
 * @Author: yuta
 * @Date: 2021-06-15 15:34:23
 * @LastEditTime: 2021-06-21 17:44:42
 * @LastEditors: yuta
 */
import React, {useState} from 'react';
import {ScrollView, Text, View} from 'react-native';
import {shadowDefault, showMsg, px2dp} from '../utils/index';
import DebugManager from '../DebugManager';

export default function LogHttp() {
  const [dataList, ,] = useState(DebugManager.LogManager.getHttpLogs());

  const renderOneLine = (title, value) => {
    return (
      <Text
        style={{
          marginVertical: px2dp(2),
          paddingVertical: px2dp(3),
          paddingHorizontal: px2dp(3),
          color: '#000',
          fontSize: 12,
        }}
        onPress={() => showMsg(value)}>
        <Text style={{fontWeight: 'bold'}}>{title}</Text>
        {value}
      </Text>
    );
  };

  return (
    <ScrollView>
      {dataList?.map((item, index) => {
        return (
          <View
            key={index}
            style={{
              marginTop: index === 0 ? px2dp(12) : 0,
              marginHorizontal: px2dp(20),
              backgroundColor: '#F8F8F8',
              borderRadius: 4,
              paddingHorizontal: px2dp(10),
              paddingTop: px2dp(20),
              paddingBottom: px2dp(24),
              marginBottom: px2dp(15),
              ...shadowDefault,
            }}>
            {renderOneLine('请求状态：', item.status ? '✅✅✅' : '❌❌❌')}
            {renderOneLine('接口名：', item.apiName)}
            {renderOneLine('请求Url：', item.url)}
            {renderOneLine('请求方式：', item.method)}
            {renderOneLine('param：', item.param)}
            {item.headers && renderOneLine('请求Headers：', item.headers)}
            {renderOneLine('请求结果：', item.result)}
            {renderOneLine('请求时间：', item.timeStr)}
          </View>
        );
      })}
    </ScrollView>
  );
}
